@@ -1,7 +1,7 @@
 package PERLANCAR::File::HomeDir;
 
-our $DATE = '2015-04-08'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-10-07'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -25,7 +25,8 @@ sub get_my_home_dir {
             if $ENV{HOMEDRIVE} && $ENV{HOMEPATH};
     } else {
         return $ENV{HOME} if $ENV{HOME};
-        my @pw = getpwuid($>);
+        my @pw;
+        eval { @pw = getpwuid($>) };
         return $pw[7] if @pw;
     }
 
@@ -51,7 +52,7 @@ PERLANCAR::File::HomeDir - Lightweight way to get current user's home directory
 
 =head1 VERSION
 
-This document describes version 0.02 of PERLANCAR::File::HomeDir (from Perl distribution PERLANCAR-File-HomeDir), released on 2015-04-08.
+This document describes version 0.03 of PERLANCAR::File::HomeDir (from Perl distribution PERLANCAR-File-HomeDir), released on 2016-10-07.
 
 =head1 SYNOPSIS
 
@@ -81,10 +82,6 @@ None are exported by default, but they are exportable.
 Try several ways to get home directory. Return undef or die (depends on
 C<$DIE_ON_FAILURE>) if everything fails.
 
-=head1 SEE ALSO
-
-L<File::HomeDir>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/PERLANCAR-File-HomeDir>.
@@ -101,13 +98,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<File::HomeDir>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
